 /*
 * ELEKTOR PIC18flash temperature sensor example
 * Author : Peter Moreton
 * 
 * Hardware: Dallas/Maxim DS1820, DS18S20 or DS18B20 temperature sensor
 * connected to header JP2. Pin 1 (GND) to JP2/10, Pin 2 (DQ) to JP2/7,
 * Pin 3 (Vdd) to JP2/2.	
 *
 * NOTE: This code enables the MCU's 4x PLL, and runs at FOSC=16Mhz. 
 * After programming this firmware for the first time, cycle power 
 * to activate the PLL.
 * 
 */
#include <p18cxxx.h>
#include <p18f452.h>
#include <stdlib.h>
#include <timers.h>
#include <delays.h>
#include <reset.h>
#include <usart.h>
#include <string.h>
#include <ctype.h>
#include "1wire.h"
#include "ftoa.h"
#include "xusart.h"
#include "PICDelay.h"

// Initialize the processor config registers


void main (void)
{
  	float Celsius, Fahrenheit, Kelvin;
	char TempStr[16];

	// Setup the PIC's ports for either input or output. '1' bit is input, '0' bit is output
	TRISA = 0b00000000;								// RA0,1,2,3 are LED's. RA4 is Dallas 'DQ'

	// Open hardware USART with SPBRG of 64= 19200,8,N,1 baud @ 20Mhz FOSC.
	// (Use Hyperterminal configured as 19,200 baud, 8N1, no flow control to view data)
	OpenUSART( USART_TX_INT_OFF &USART_RX_INT_OFF &USART_ASYNCH_MODE &USART_EIGHT_BIT &USART_CONT_RX &USART_BRGH_HIGH,64 );

 	xputrsUSART("\n\r\n\rELEKTOR Remote Temperature Logger");
 	xputrsUSART("\n\rFirmware revision v1.0\n\r");


//	OWCalibrate(5);
	while (1)										// forever
	{
		Convert_Temperature();						// initiate a convert
		DelayMS(3000);								// wait for convert to complete

		// NOTE: YOU MUST UN-COMMENT THE DEVICE TYPE THAT YOU ARE USING 
		Celsius = Read_Temperature_DS18S20();		// use DS18S20 device
	//	Celsius = Read_Temperature_DS18B20();		// use DS18B20 device


		ftoa (Celsius, TempStr, 2, 'F');			// convert float to string
		xputrsUSART("\n\rCelsius: "); 
		xputsUSART(TempStr);

		Fahrenheit = ((Celsius * 9) / 5) + 32;
		ftoa (Fahrenheit, TempStr, 2, 'F');			// convert float to string
		xputrsUSART("  Fahrenheit: "); 
		xputsUSART(TempStr);

		Kelvin = Celsius + 273.15;
		ftoa (Kelvin, TempStr, 2, 'F');				// convert float to string
		xputrsUSART("  Kelvin: "); 
		xputsUSART(TempStr);

	}
}
